[![Build Status](https://travis-ci.org/raphaeldussin/DICRIVERS.svg?branch=master)](https://travis-ci.org/raphaeldussin/DICRIVERS)

# DICRIVERS
A preprocessing tool to specify river biogeochemistry input for ocean models

This tool is intended to be use by ocean modelers to specify river concentrations of nutrients or other biogeochemical
variable of interest (DIC, Alkalinity,...). It produces gridded fields of river concentrations from a pandas.dataframe
Its name is a tribute to singer Dick Rivers, who made a living covering american classic tunes in french with a
significant loss in musicality. See full documentation here:

[doc](https://dicrivers.readthedocs.io/en/latest/)
